@@ -87,3 +87,33 @@ def str2file(content="hello world!", fileName="data.txt", RelativePath="\\"):
         file.write(content)
 
     return True
+
+
+# 移除某个目录下特定文件类型的文件名前缀（默认所有类型文件）
+def removeFileNamePrefix(fileNamePrefix='', folderPath='', fileType='*'):
+    if folderPath == '' or fileNamePrefix == '':
+        # 文件固定前缀/文件夹路径为空
+        return False
+
+    fileList = os.listdir(folderPath)
+
+    for fileName in fileList:
+        if fileType != '*' and fileType not in fileName:
+            # 文件类型检查
+            continue
+
+        oldFilePath = f"{folderPath}/{fileName}"
+
+        # 跳过目录
+        if os.path.isdir(oldFilePath):
+            continue
+
+        newFileName = fileName.replace(fileNamePrefix, "")
+        newFilePath = f"{folderPath}/{newFileName}"
+        try:
+            os.rename(oldFilePath, newFilePath)
+        except Exception as e:
+            print(e)
+            return False
+
+    return True
